@@ -7,7 +7,7 @@ static GLOBAL: AsyncAllocatorCounter<System> = AsyncAllocatorCounter { allocator
 
 #[tokio::main]
 async fn main() {
-    for i in 1..1000 {
+    for i in 1..100 {
         let f = async move {
             let mut v = Vec::new();
 
@@ -19,7 +19,7 @@ async fn main() {
                         println!("{}", s);
                         tokio::time::sleep(Duration::from_millis(100)).await;
                     }
-                    .trace(i * 1000 + j)
+                    .count_allocations()
                     .map(move |(max, ())| {
                         println!("inner task {} allocated {} max bytes", i * 1000 + j, max);
                     }),
@@ -28,7 +28,7 @@ async fn main() {
                 .unwrap();
             }
         }
-        .trace(i)
+        .count_allocations()
         .map(move |(max, ())| {
             println!("task {} allocated {} max bytes", i, max);
         });
